| Title: | Interactively browse pins and their metadata in RStudio |
|---|---|
| Description: | Browse the content of boards created with the pins package. View and search available pins, view their metadata, and generate code to read pins into your current project. |
| Authors: | Sam Gardiner [aut, cre] (ORCID: <https://orcid.org/0000-0002-6752-6969>) |
| Maintainer: | Sam Gardiner <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-25 10:27:48 UTC |
| Source: | https://github.com/gardiners/pinbrowser |
Generate a pins::board_temp() using R's built-in datasets mtcars,
BJsales, beaver1, and some of their metadata.
board_demo()board_demo()
my_board <- board_demo()my_board <- board_demo()
Opens a Shiny app to explore available pins and their metadata.
browse_board(board)browse_board(board)
board |
A pin board, created by |
## Not run: my_board <- board_demo() browse_board(my_board) ## End(Not run)## Not run: my_board <- board_demo() browse_board(my_board) ## End(Not run)